@@ -1,5 +1,6 @@
 /*
- * LALMetaIOVCSInfo.h - LALMetaIO VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALMetaIOVCSInfo.h - LALMetaIO VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALMETAIO_NAME "LALMetaIO"
-#define LALMETAIO_VCS_ID "56ff002180ff37a1dfbc3f5c88d98fa21d226d1f"
-#define LALMETAIO_VCS_DATE "2016-10-10 17:31:34 +0000"
+/* VCS information */
+#define LALMETAIO_VCS_ID "7619993d359a9050da0017a7a441327e724fc70b"
+#define LALMETAIO_VCS_DATE "2017-02-6 18:15:58 +0000"
 #define LALMETAIO_VCS_BRANCH "None"
-#define LALMETAIO_VCS_TAG "lalmetaio-v1.3.0"
+#define LALMETAIO_VCS_TAG "lalmetaio-v1.3.1"
 #define LALMETAIO_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALMETAIO_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALMETAIO_VCS_CLEAN "CLEAN"
 #define LALMETAIO_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALMETAIO_VCS_IDENT_ID "$" "LALMetaIOId: 56ff002180ff37a1dfbc3f5c88d98fa21d226d1f " "$"
-#define LALMETAIO_VCS_IDENT_DATE "$" "LALMetaIODate: 2016-10-10 17:31:34 +0000 " "$"
-#define LALMETAIO_VCS_IDENT_BRANCH "$" "LALMetaIOBranch: None " "$"
-#define LALMETAIO_VCS_IDENT_TAG "$" "LALMetaIOTag: lalmetaio-v1.3.0 " "$"
-#define LALMETAIO_VCS_IDENT_AUTHOR "$" "LALMetaIOAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALMETAIO_VCS_IDENT_COMMITTER "$" "LALMetaIOCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALMETAIO_VCS_IDENT_STATUS "$" "LALMetaIOStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalMetaIOVCSInfoHeader = { \
-  LALMETAIO_NAME, \
-  LALMETAIO_VERSION, \
-  LALMETAIO_VCS_ID, \
-  LALMETAIO_VCS_DATE, \
-  LALMETAIO_VCS_BRANCH, \
-  LALMETAIO_VCS_TAG, \
-  LALMETAIO_VCS_AUTHOR, \
-  LALMETAIO_VCS_COMMITTER, \
-  LALMETAIO_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALMETAIO_VCS_LINK_CHECK LALMETAIO_CLEAN_7619993d359a9050da0017a7a441327e724fc70b_VCS_HEADER_LIBRARY_MISMATCH
+void LALMETAIO_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalMetaIOVCSInfoHeader = { \
 #endif /* _LALMETAIOVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
